==> bingefriend_shows_core-0.1.3.tar.gz: bingefriend_shows_core-0.1.3/src/bingefriend/shows/core/models/show.py <==
"""SQLAlchemy model for a show."""

from typing import Optional
import datetime
import typing
from sqlalchemy import String, Integer, Date, ForeignKey, Text
from sqlalchemy.orm import mapped_column, Mapped, relationship
from .base import Base

if typing.TYPE_CHECKING:
    from .episode import Episode
    from .network import Network
    from .season import Season
    from .show_genre import ShowGenre


class Show(Base):
    """SQLAlchemy model for a show."""

    __tablename__ = "shows"

    # Attributes
    id: Mapped[int] = mapped_column(primary_key=True)
    maze_id: Mapped[int] = mapped_column(unique=True, nullable=False)
    url: Mapped[Optional[str]] = mapped_column(String(255))
    name: Mapped[str] = mapped_column(String(255), nullable=False)
    type: Mapped[str] = mapped_column(String(255), nullable=False)
    language: Mapped[Optional[str]] = mapped_column(String(255))
    status: Mapped[Optional[str]] = mapped_column(String(255))
    runtime: Mapped[Optional[int]] = mapped_column(Integer)
    averageRuntime: Mapped[Optional[int]] = mapped_column(Integer)
    premiered: Mapped[Optional[datetime.date]] = mapped_column(Date)
    ended: Mapped[Optional[datetime.date]] = mapped_column(Date)
    schedule_time: Mapped[Optional[str]] = mapped_column(String(255))
    schedule_days: Mapped[Optional[str]] = mapped_column(String(255))
    network_id: Mapped[Optional[int]] = mapped_column(ForeignKey("networks.id"))
    webChannel: Mapped[Optional[str]] = mapped_column(String(255))
    externals_imdb: Mapped[Optional[str]] = mapped_column(String(255))
    image_medium: Mapped[Optional[str]] = mapped_column(String(255))
    image_original: Mapped[Optional[str]] = mapped_column(String(255))
    summary: Mapped[Optional[str]] = mapped_column(Text)
    updated: Mapped[Optional[int]] = mapped_column(Integer)

    # Relationships - referenced in this model
    seasons: Mapped["Season"] = relationship(back_populates="show", cascade="all, delete-orphan")
    episodes: Mapped["Episode"] = relationship(back_populates="show", cascade="all, delete-orphan")

    # Relationships - referencing this model
    network: Mapped["Network"] = relationship(back_populates="shows")
    show_genres: Mapped[list["ShowGenre"]] = relationship(back_populates="show")

==> bingefriend_shows_core-0.2.1.tar.gz: bingefriend_shows_core-0.2.1/src/bingefriend/shows/core/models/show.py <==
"""SQLAlchemy model for a show."""

import datetime
from typing import Optional, TYPE_CHECKING
from sqlalchemy import String, Integer, Date, ForeignKey, Text
from sqlalchemy.orm import mapped_column, Mapped, relationship
from bingefriend.shows.core.models.base import Base

if TYPE_CHECKING:
    from bingefriend.shows.core.models.episode import Episode
    from bingefriend.shows.core.models.network import Network
    from bingefriend.shows.core.models.season import Season
    from bingefriend.shows.core.models.show_genre import ShowGenre


class Show(Base):
    """SQLAlchemy model for a show."""

    __tablename__ = "shows"

    # Attributes
    id: Mapped[int] = mapped_column(primary_key=True)
    maze_id: Mapped[int] = mapped_column(unique=True, nullable=False)
    url: Mapped[Optional[str]] = mapped_column(String(255))
    name: Mapped[str] = mapped_column(String(255), nullable=False)
    type: Mapped[str] = mapped_column(String(255), nullable=False)
    language: Mapped[Optional[str]] = mapped_column(String(255))
    status: Mapped[Optional[str]] = mapped_column(String(255))
    runtime: Mapped[Optional[int]] = mapped_column(Integer)
    averageRuntime: Mapped[Optional[int]] = mapped_column(Integer)
    premiered: Mapped[Optional[datetime.date]] = mapped_column(Date)
    ended: Mapped[Optional[datetime.date]] = mapped_column(Date)
    schedule_time: Mapped[Optional[str]] = mapped_column(String(255))
    schedule_days: Mapped[Optional[str]] = mapped_column(String(255))
    network_id: Mapped[Optional[int]] = mapped_column(ForeignKey("networks.id"))
    webChannel_id: Mapped[Optional[int]] = mapped_column(ForeignKey("web_channel.id"))
    externals_imdb: Mapped[Optional[str]] = mapped_column(String(255))
    image_medium: Mapped[Optional[str]] = mapped_column(String(255))
    image_original: Mapped[Optional[str]] = mapped_column(String(255))
    summary: Mapped[Optional[str]] = mapped_column(Text)
    updated: Mapped[Optional[int]] = mapped_column(Integer)

    # Relationships - referenced in this model
    network: Mapped["Network"] = relationship(back_populates="shows")
    web_channel: Mapped[Optional["WebChannel"]] = relationship(back_populates="shows")

    # Relationships - referencing this model
    show_genres: Mapped[list["ShowGenre"]] = relationship(back_populates="show")
    seasons: Mapped["Season"] = relationship(back_populates="show", cascade="all, delete-orphan")
    episodes: Mapped["Episode"] = relationship(back_populates="show", cascade="all, delete-orphan")
